"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = default_1;
const schematics_1 = require("@angular-devkit/schematics");
const ng_ast_utils_1 = require("@schematics/angular/utility/ng-ast-utils");
const ast_utils_1 = require("@schematics/angular/utility/ast-utils");
const module_1 = require("@po-ui/ng-schematics/module");
const project_1 = require("@po-ui/ng-schematics/project");
/** PO Module name that will be inserted into app root module */
const poStorageModuleName = 'PoStorageModule.forRoot()';
const poStorageModuleSourcePath = '@po-ui/ng-storage';
const poPoSyncModuleName = 'PoSyncModule';
const poPoSyncModuleSourcePath = '@po-ui/ng-sync';
/** HttpClient Module name that will insert in app root module */
const httpProvideHttpClientName = 'provideHttpClient';
const httpWithInterceptorsFromDiName = 'withInterceptorsFromDi';
const httpClientModuleSourcePath = '@angular/common/http';
function default_1(options) {
    return (0, schematics_1.chain)([
        addModuleImportToRootModuleSync(options, poStorageModuleName, poStorageModuleSourcePath),
        addModuleImportToRootModuleSync(options, poPoSyncModuleName, poPoSyncModuleSourcePath),
        addImportOnly(options, [httpProvideHttpClientName, httpWithInterceptorsFromDiName], httpClientModuleSourcePath),
        addProviderToAppModule(options, 'provideHttpClient(withInterceptorsFromDi()),'),
        updateEntryPointFileRule(options)
    ]);
}
function addModuleImportToRootModuleSync(options, moduleName, modulePath) {
    return (host) => {
        var _a;
        const workspace = (_a = (0, project_1.getWorkspaceConfigGracefully)(host)) !== null && _a !== void 0 ? _a : {};
        const project = (0, project_1.getProjectFromWorkspace)(workspace, options.project);
        const browserEntryPoint = getProjectMainFileSync(project);
        if (!browserEntryPoint || (0, ng_ast_utils_1.isStandaloneApp)(host, browserEntryPoint)) {
            return host;
        }
        const appModulePath = (0, ng_ast_utils_1.getAppModulePath)(host, browserEntryPoint);
        if (!(0, module_1.hasNgModuleImport)(host, appModulePath, moduleName)) {
            (0, module_1.addModuleImportToModule)(host, appModulePath, moduleName, modulePath);
        }
        return host;
    };
}
function addImportOnly(options, moduleNames, importPath) {
    return (host) => {
        var _a;
        const workspace = (_a = (0, project_1.getWorkspaceConfigGracefully)(host)) !== null && _a !== void 0 ? _a : {};
        const project = (0, project_1.getProjectFromWorkspace)(workspace, options.project);
        const browserEntryPoint = getProjectMainFileSync(project);
        if (!browserEntryPoint || (0, ng_ast_utils_1.isStandaloneApp)(host, browserEntryPoint)) {
            return host;
        }
        const modulePath = (0, ng_ast_utils_1.getAppModulePath)(host, browserEntryPoint);
        let importStatement;
        if (Array.isArray(moduleNames)) {
            const names = moduleNames.join(', ');
            importStatement = `import { ${names} } from '${importPath}';\n`;
        }
        else {
            importStatement = `import { ${moduleNames} } from '${importPath}';\n`;
        }
        const recorder = host.beginUpdate(modulePath);
        recorder.insertLeft(0, importStatement);
        host.commitUpdate(recorder);
        return host;
    };
}
function addProviderToAppModule(options, provider) {
    return (host) => {
        var _a;
        const workspace = (_a = (0, project_1.getWorkspaceConfigGracefully)(host)) !== null && _a !== void 0 ? _a : {};
        const project = (0, project_1.getProjectFromWorkspace)(workspace, options.project);
        const browserEntryPoint = getProjectMainFileSync(project);
        if (!browserEntryPoint || (0, ng_ast_utils_1.isStandaloneApp)(host, browserEntryPoint)) {
            return host;
        }
        const appModulePath = (0, ng_ast_utils_1.getAppModulePath)(host, browserEntryPoint);
        addProviderToModuleProvider(host, appModulePath, provider);
        return host;
    };
}
function updateEntryPointFileRule(options) {
    const pathMain = 'src/main.ts';
    const pathAppConfig = 'src/app/app.config.ts';
    let pathFile;
    let conteudoModificado;
    return (tree) => {
        var _a, _b;
        const workspace = (_a = (0, project_1.getWorkspaceConfigGracefully)(tree)) !== null && _a !== void 0 ? _a : {};
        const project = (0, project_1.getProjectFromWorkspace)(workspace, options.project);
        const browserEntryPoint = getProjectMainFileSync(project, 'browser');
        if (!browserEntryPoint || !(0, ng_ast_utils_1.isStandaloneApp)(tree, browserEntryPoint)) {
            return tree;
        }
        if (!tree.exists(pathAppConfig)) {
            pathFile = pathMain;
            conteudoModificado = updateMainFile();
        }
        else {
            pathFile = pathAppConfig;
            const content = ((_b = tree.read('src/app/app.config.ts')) === null || _b === void 0 ? void 0 : _b.toString('utf-8')) || '';
            conteudoModificado = updateAppConfigFile(content);
        }
        tree.overwrite(pathFile, conteudoModificado);
        return tree;
    };
}
function addProviderToModuleProvider(tree, modulePath, provider) {
    const moduleSource = (0, module_1.getSourceFile)(tree, modulePath);
    const changes = (0, ast_utils_1.addProviderToModule)(moduleSource, modulePath, `
    ${provider}`, null);
    return insertChanges(tree, changes, modulePath);
}
function getProjectMainFileSync(project, property = 'main') {
    const buildOptions = (0, project_1.getProjectTargetOptions)(project, 'build');
    if (!buildOptions[property]) {
        return null;
    }
    return buildOptions[property];
}
function insertChanges(tree, changes, modulePath) {
    const recorder = tree.beginUpdate(modulePath);
    changes.forEach(change => {
        if (change) {
            recorder.insertLeft(change.pos, change.toAdd);
        }
    });
    tree.commitUpdate(recorder);
}
function updateMainFile() {
    return `
import { bootstrapApplication } from '@angular/platform-browser';
import { RouteReuseStrategy, provideRouter, withPreloading, PreloadAllModules } from '@angular/router';
import { IonicRouteStrategy, provideIonicAngular } from '@ionic/angular/standalone';
import { importProvidersFrom } from '@angular/core';
import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http';

import { PoSyncModule } from '@po-ui/ng-sync';
import { PoStorageModule } from '@po-ui/ng-storage';

import { routes } from './app/app.routes';
import { AppComponent } from './app/app.component';

bootstrapApplication(AppComponent, {
  providers: [
    { provide: RouteReuseStrategy, useClass: IonicRouteStrategy },
    provideIonicAngular(),
    provideRouter(routes, withPreloading(PreloadAllModules)),
    provideHttpClient(withInterceptorsFromDi()),
    importProvidersFrom(PoSyncModule),
    importProvidersFrom(PoStorageModule.forRoot())
  ],
});`.trim();
}
function updateAppConfigFile(content) {
    const importBlock = `
import { provideHttpClient, withInterceptorsFromDi } from '@angular/common/http';

import { PoSyncModule } from '@po-ui/ng-sync';
import { PoStorageModule } from '@po-ui/ng-storage';
`;
    const providersBlock = `
  providers: [
    provideRouter(routes),
    provideHttpClient(),
    provideZoneChangeDetection({ eventCoalescing: true }),
    provideHttpClient(withInterceptorsFromDi()),
    importProvidersFrom(PoSyncModule),
    importProvidersFrom(PoStorageModule.forRoot())
  ],`;
    const regexImport = /import {[^}]+} from '@angular\/core';/;
    const regexProviders = /providers: \[[^\]]+\]/;
    // Remove imports e providers existentes
    let modifiedContent = content.replace(regexImport, '').replace(regexProviders, '');
    // Adiciona os novos imports e providers
    modifiedContent = modifiedContent.replace(/export const appConfig: ApplicationConfig = {/, `import { ApplicationConfig, importProvidersFrom, provideZoneChangeDetection } from '@angular/core';${importBlock}
export const appConfig: ApplicationConfig = {${providersBlock}`);
    return modifiedContent.trim();
}
//# sourceMappingURL=setup-project.js.map